pub struct Deadline { /* private fields */ }Expand description
Expire at a specific SystemTime.
Implementations
Sourceimpl Deadline
impl Deadline
pub fn new(at: SystemTime) -> Self
Sourcepub fn reset(&mut self, to: SystemTime)
pub fn reset(&mut self, to: SystemTime)
Race
There is a race condition if the deadline is reset after after the reactor has been notified.